@@ -19,6 +19,15 @@ bool seed_uniform(Rcpp::IntegerVector seed) {
   return Rcpp::is_true(Rcpp::all(u1 == u2));
 }
 
+// [[Rcpp::export]]
+bool seed_uniform_scalar(Rcpp::IntegerVector seed) {
+  dqrng::dqset_seed(seed);
+  double u1 = dqrng::runif();
+  dqrng::dqset_seed(seed);
+  double u2 = dqrng::runif();
+  return u1 == u2;
+}
+
 // [[Rcpp::export]]
 bool seed_normal(Rcpp::IntegerVector seed) {
   dqrng::dqset_seed(seed);
@@ -28,6 +37,15 @@ bool seed_normal(Rcpp::IntegerVector seed) {
   return Rcpp::is_true(Rcpp::all(n1 == n2));
 }
 
+// [[Rcpp::export]]
+bool seed_normal_scalar(Rcpp::IntegerVector seed) {
+  dqrng::dqset_seed(seed);
+  double n1 = dqrng::rnorm();
+  dqrng::dqset_seed(seed);
+  double n2 = dqrng::rnorm();
+  return n1 == n2;
+}
+
 // [[Rcpp::export]]
 bool seed_exponential(Rcpp::IntegerVector seed) {
   dqrng::dqset_seed(seed);
@@ -37,3 +55,11 @@ bool seed_exponential(Rcpp::IntegerVector seed) {
   return Rcpp::is_true(Rcpp::all(e1 == e2));
 }
 
+// [[Rcpp::export]]
+bool seed_exponential_scalar(Rcpp::IntegerVector seed) {
+  dqrng::dqset_seed(seed);
+  double u1 = dqrng::rexp();
+  dqrng::dqset_seed(seed);
+  double u2 = dqrng::rexp();
+  return u1 == u2;
+}
